//Journal of Money, Credit and Banking MS20-487
//Ambrose, Coulson, and Yoshida
//January 30, 2022



// ====================================
// Construct MRI and modified inflation rates

cd "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code"

set matsize 1000
set more off
set type double

use "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\inflation_m_MS20-487.dta", replace

	
// obtain moments
sum rri_pcq_m NOI_apt_pcq_m if qr >= tq(2001q2) & qr <= tq(2010q1)

// generate standardized NOI
sum NOI_apt_pch_m if qr >= tq(2001q2) & qr <= tq(2010q1) 

gen SNOI_apt_pch_m = .
replace SNOI_apt_pch_m = (NOI_apt_pch_m - r(mean) ) / r(sd)
sum SNOI_apt_pch_m if qr >= tq(2001q2) & qr <= tq(2010q1) 

// Construct monthly mri by modifying mean and stdev 
// so that the quarterly growth mri_pcq_m has the same moments as RRI

//initial guess
gen mri_pch_m = -0.02327952 + 0.50597785 * SNOI_apt_pch_m //monthly mri

label variable mri_pch_m "Marginal Rent Index"

gen mri_lin_m = . // mri level
replace mri_lin_m = 100 if mo == tm(2001m3) 
replace mri_lin_m = mri_lin_m[_n-1] * (1 + mri_pch_m[_n]/100) if mo > tm(2001m3) 
label variable mri_lin_m "Marginal Rent Index"

gen mri_pcq_m = . // MRI non-overlapping quarterly growth rates
replace mri_pcq_m = ( mri_lin_m[_n]/mri_lin_m[_n-3] - 1 ) *100 ///
	if md == 3 | md == 6 | md == 9 | md == 12
label variable mri_pcq_m "Quarterly Growth in Marginal Rent Index"

sum mri_pcq_m if qr >= tq(2001q2) & qr <= tq(2010q1) 

// final conversion equation

sum mri_pcq_m if qr >= tq(2001q2) & qr <= tq(2010q1) 
local mn_mri = r(mean)
local sd_mri = r(sd)
sum rri_pcq_m if qr >= tq(2001q2) & qr <= tq(2010q1) 
local mn_rri = r(mean)
local sd_rri = r(sd)

local a = -0.03927653 
local b = 0.4850342
replace mri_pch_m = `a' + `b' * SNOI_apt_pch_m //monthly mri

// minimizing sd errors
local er_sd = 1.1 // error 
while abs(`er_sd' - 1) > 0.00000001{
	local b = `b' / ((`er_sd' - 1)/2 + 1 )
	replace mri_pch_m = `a' + `b' * SNOI_apt_pch_m //monthly mri
	
	replace mri_lin_m = mri_lin_m[_n-1] * (1 + mri_pch_m[_n]/100) if mo > tm(2001m3) 
	replace mri_pcq_m = ( mri_lin_m[_n]/mri_lin_m[_n-3] - 1 ) *100 ///
	if md == 3 | md == 6 | md == 9 | md == 12
	sum mri_pcq_m if qr >= tq(2001q2) & qr <= tq(2010q1) 
	local sd_mri = r(sd)
	local er_sd = `sd_mri' / `sd_rri'
	display "error sd: " `er_sd'
}

// minimizing mean errors
local er_mn = 0.1 // error 
while abs(`er_mn') > 0.00000001{
	local a = `a' - `er_mn' / 2 
	replace mri_pch_m = `a' + `b' * SNOI_apt_pch_m //monthly mri
	
	replace mri_lin_m = mri_lin_m[_n-1] * (1 + mri_pch_m[_n]/100) if mo > tm(2001m3) 
	replace mri_pcq_m = ( mri_lin_m[_n]/mri_lin_m[_n-3] - 1 ) *100 ///
	if md == 3 | md == 6 | md == 9 | md == 12
	sum mri_pcq_m if qr >= tq(2001q2) & qr <= tq(2010q1) 
	local mn_mri = r(mean)
	local er_mn = `mn_mri' - `mn_rri'
	display "error mn: " `er_mn'
}

// Result
display "mri_pch_m = " `a' " + " `b' " * SNOI_apt_pch_m "
/*
mri_pch_m = -.03926877 + .48602789 * SNOI_apt_pch_m 
*/
replace mri_pch_m =  `a' + `b' * SNOI_apt_pch_m 
replace mri_lin_m = mri_lin_m[_n-1] * (1 + mri_pch_m[_n]/100) if mo > tm(2001m3) 
replace mri_pcq_m = ( mri_lin_m[_n]/mri_lin_m[_n-3] - 1 ) *100 ///
	if md == 3 | md == 6 | md == 9 | md == 12
sum rri_pcq_m mri_pcq_m if qr >= tq(2001q2) & qr <= tq(2010q1) 

drop SNOI_apt_pch_m 


gen mri_pc1_m = . 
replace mri_pc1_m = ( mri_lin_m[_n]/mri_lin_m[_n-12] - 1 ) *100 
label variable mri_pc1_m "Marginal Rent Index"

sum mri_pc1_m if qr >= tq(2001q2) & qr <= tq(2010q1) 




// ----------------------------------
// Replace rents with MRI

// construct monthly growth (pch) of the modified price index
gen cpiaucmod_pch_m =  wcpi_shelterrent_all  * mri_pch_m ///
					+ (1 - wcpi_shelterrent_all ) * cpiaucexrent_pch_m 
label variable cpiaucmod_pch_m "Modified CPI"

gen cpilfemod_pch_m =  wcpi_shelterrent_core  * mri_pch_m ///
					+ (1 -  wcpi_shelterrent_core) * cpilfeexrent_pch_m 
label variable cpilfemod_pch_m "Modified Core CPI"
  
gen PCEPImod_pch_m =  wpce_housing * mri_pch_m ///
					+ (1 -  wpce_housing) * PCEPIlh_pch_m
label variable PCEPImod_pch_m "Modified PCE"

gen PCEPILFEmod_pch_m=  wpce_housing_core * mri_pch_m ///
					+ (1 -  wpce_housing_core) * PCEPILFEh_pch_m
label variable PCEPILFEmod_pch_m "Modified Core PCE"


// generate index level (lin) and the percentage change from year ago (pc1)
foreach i in cpiaucmod cpilfemod PCEPImod PCEPILFEmod {

local l`i' : variable label `i'_pch_m
gen `i'_lin_m =.
label variable `i'_lin_m "`l`i''"
replace `i'_lin_m = 100 if mo == tm(2001m3)
replace `i'_lin_m = `i'_lin_m[_n-1] * (1 + `i'_pch_m / 100 ) if mo > tm(2001m3)

gen `i'_pc1_m = .
label variable `i'_pc1_m "`l`i''"
replace `i'_pc1_m = (`i'_lin_m[_n] / `i'_lin_m[_n-12] - 1)*100
}


gen wcpi_rent_shelter =  wcpi_rent_primary /  wcpi_shelterrent_all
label variable wcpi_rent_shelter "Rent of Primary Residence in Shelter"

gen wcpi_oer_shelter =  wcpi_oer /  wcpi_shelterrent_all
label variable wcpi_oer_shelter "Owners' Equivalent Rent in Shelter"

gen wpce_tenant_housing =  wpce_tenant /  wpce_housing
label variable wpce_tenant_housing "Rental of Tenant Occupied Housing in Housing"

gen wpce_owner_housing =  wpce_owner /  wpce_housing
label variable wpce_owner_housing "Rental of Owner Occupied Housing in Housing"




	

// Gap in Inflation Rates 

*Headline inflation index: The difference in YOY growth

gen gap_cpiauc_pc1_m = cpiaucmod_pc1_m - CPIAUCSL_pc1_m
label variable gap_cpiauc_pc1_m "Difference between original and modified CPI"

gen gap_PCEPI_pc1_m = PCEPImod_pc1_m - PCEPI_pc1_m
label variable gap_PCEPI_pc1_m "Difference between original and modified PCE"



*Core index: The difference in YOY growth

gen gap_cpilfe_pc1_m = cpilfemod_pc1_m - CPILFESL_pc1_m
label variable gap_cpilfe_pc1_m "Difference between original and modified core CPI"

gen gap_PCEPILFE_pc1_m = PCEPILFEmod_pc1_m - PCEPILFE_pc1_m
label variable gap_PCEPILFE_pc1_m "Difference between original and modified core PCE"


*Headline inflation index: The difference in monthly growth

gen gap_cpiauc_pch_m = cpiaucmod_pch_m - CPIAUCSL_pch_m
label variable gap_cpiauc_pch_m "Difference between original and modified CPI"

gen gap_PCEPI_pch_m = PCEPImod_pch_m - PCEPI_pch_m
label variable gap_PCEPI_pch_m "Difference between original and modified PCE"



*Core index: The difference in monthly growth

gen gap_cpilfe_pch_m = cpilfemod_pch_m - CPILFESL_pch_m
label variable gap_cpilfe_pch_m "Difference between original and modified core CPI"

gen gap_PCEPILFE_pch_m = PCEPILFEmod_pch_m - PCEPILFE_pch_m
label variable gap_PCEPILFE_pch_m "Difference between original and modified core PCE"



*Annualized quarterly changes
foreach v in CPIAUCSL cpiaucmod PCEPI PCEPImod CPILFESL cpilfemod PCEPILFE PCEPILFEmod mri pcehpi CUSR0000SAS2RS{
gen `v'_pca_m =  `v'_pch_m * 12
local l`v' : variable label `v'_pch_m
label variable `v'_pca_m "`l`v''"
}

*Headline inflation index: The difference in annualized monthly growth

gen gap_cpiauc_pca_m = cpiaucmod_pca_m - CPIAUCSL_pca_m
label variable gap_cpiauc_pca_m "Difference between original and modified CPI"

gen gap_PCEPI_pca_m = PCEPImod_pca_m - PCEPI_pca_m
label variable gap_PCEPI_pca_m "Difference between original and modified PCE"



*Core index: The difference in annualized monthly growth

gen gap_cpilfe_pca_m = cpilfemod_pca_m - CPILFESL_pca_m
label variable gap_cpilfe_pca_m "Difference between original and modified core CPI"

gen gap_PCEPILFE_pca_m = PCEPILFEmod_pca_m - PCEPILFE_pca_m
label variable gap_PCEPILFE_pca_m "Difference between original and modified core PCE"
	

keep mo qr yr qd md cpilfemod_lin_m cpiaucmod_lin_m mri_lin_m ///
	cpiaucmod_pc1_m CPIAUCSL_pc1_m PCEPImod_pc1_m PCEPI_pc1_m nber_rec ///
	CUSR0000SAS2RS_pc1_m pcehpi_pc1_m mri_pc1_m ///
	gap_cpiauc_pc1_m gap_PCEPI_pc1_m cpilfemod_pc1_m CPILFESL_pc1_m  ///
	PCEPILFEmod_pc1_m PCEPILFE_pc1_m gap_cpilfe_pc1_m gap_PCEPILFE_pc1_m ///
	pcerti_pch_m pcerti_pc1_m mri_pch_m mri_pc1_m ///
	CPIAUCSL_pca_m cpiaucmod_pca_m gap_cpiauc_pca_m ///
	PCEPI_pca_m PCEPImod_pca_m gap_PCEPI_pca_m ///
	CPILFESL_pca_m cpilfemod_pca_m gap_cpilfe_pca_m ///
	PCEPILFE_pca_m PCEPILFEmod_pca_m gap_PCEPILFE_pca_m ///
	NOI_apt_pch_m NOI_apt_lin_m rri_pcq_m

	
save "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\modified_inflation_m_MS20-487.dta", replace



// ====================================
// Graphs Monthly	

cd "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code"

set matsize 4000
set more off
set type double
set scheme s2mono

use "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\modified_inflation_m_MS20-487.dta", clear

tsset mo


//-----------------------------------------
// normalise lin
foreach var of varlist *_lin*{
sum `var' if mo == tm(2001m9)
local ref = r(mean)
replace `var' = `var' / `ref' * 100
}



//-----------------------------------------
*Headline index: YOY growth
capture noisily drop gmax gmin
capture noisily gen gmax =.
capture noisily gen gmin =.
capture noisily replace gmax =.
capture noisily replace gmin =.

sum cpiaucmod_pc1_m if cpiaucmod_pc1_m <.
replace gmax = round(r(max)+1,2) if nber_rec == 1
replace gmin = round(r(min)-1,2) if gmin > r(min)

sum CPIAUCSL_pc1_m if cpiaucmod_pc1_m <.
replace gmax = round(r(max)+1,2) if nber_rec == 1 & gmax < r(max)
replace gmin = round(r(min)-1,2) if gmin > r(min)

sum PCEPImod_pc1_m if cpiaucmod_pc1_m <.
replace gmax = round(r(max)+1,2) if nber_rec == 1 & gmax < r(max)
replace gmin = round(r(min)-1,2) if gmin > r(min)

sum PCEPI_pc1_m if cpiaucmod_pc1_m <.
replace gmax = round(r(max)+1,2) if nber_rec == 1 & gmax < r(max)
replace gmin = round(r(min)-1,2) if gmin > r(min)

replace gmax = 0 if nber_rec == 0 
replace gmin = 0 if nber_rec == 0 
sum gmax if nber_rec == 1
local max = r(mean)
sum gmin if nber_rec == 1 
local min = r(mean)


twoway	(bar gmax mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(bar gmin mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(line CPIAUCSL_pc1_m mo, lpattern(solid)) ///
		(line cpiaucmod_pc1_m mo, lwidth(thick) lpattern(dash)) ///
		if cpiaucmod_lin_m <. ///
		,legend(pos(6) ring(1) col(2) order(3 4 1 "NBER Recessions")) ///
		graphregion(color(white)) ///
		xtitle("") xlabel(#6) ///
		ytitle("%") ylabel(#7) yscale(range(`min' `max'))

graph export "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\cpiauc_mod_pc1_m.pdf", replace


twoway	(bar gmax mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(bar gmin mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(line PCEPI_pc1_m mo, lpattern(solid)) ///
		(line PCEPImod_pc1_m mo, lwidth(thick) lpattern(dash)) ///
		if cpiaucmod_lin_m <. ///
		,legend(pos(6) ring(1) col(2) order(3 4 1 "NBER Recessions")) ///
		graphregion(color(white)) ///
		xtitle("") xlabel(#6) ///
		ytitle("%") ylabel(#7) yscale(range(`min' `max'))

graph export "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\PCEPI_mod_pc1_m.pdf", replace


*Rent index: YOY growth
capture noisily drop gmax gmin
capture noisily gen gmax =.
capture noisily gen gmin =.
capture noisily replace gmax =.
capture noisily replace gmin =.

sum CUSR0000SAS2RS_pc1_m if mri_pc1_m <.
replace gmax = round(r(max)+1,5) if nber_rec == 1
replace gmin = round(r(min)-1,5) if gmin > r(min)

sum pcehpi_pc1_m if mri_pc1_m <.
replace gmax = round(r(max)+1,5) if nber_rec == 1 & gmax < r(max)
replace gmin = round(r(min)-1,5) if gmin > r(min)

sum mri_pc1_m if mri_pc1_m <.
replace gmax = round(r(max)+1,5) if nber_rec == 1
replace gmin = round(r(min)-1,5) if gmin > r(min)

replace gmax = 0 if nber_rec == 0 
replace gmin = 0 if nber_rec == 0 
sum gmax if nber_rec == 1
local max = r(mean)
sum gmin if nber_rec == 1 
local min = r(mean)


twoway	(bar gmax mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(bar gmin mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(line pcehpi_pc1_m mo, lpattern(dash)) ///
		(line mri_pc1_m mo, lwidth(thick) lpattern(solid)) ///
		if mri_lin_m <. ///
		,legend(pos(6) ring(1) col(2) order(3 4 1 "NBER Recessions")) ///
		graphregion(color(white)) ///
		xtitle("") xlabel(#4) ///
		ytitle("%") ylabel(#7) yscale(range(`min' `max'))

graph export "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\mri_pcehpi_pc1_m.pdf", replace


*Headline index: The difference in YOY growth

*gen gap_cpiauc_pc1_m = cpiaucmod_pc1_m - CPIAUCSL_pc1_m
*label variable gap_cpiauc_pc1_m "Difference between original and modified CPI"

*gen gap_PCEPI_pc1_m = PCEPImod_pc1_m - PCEPI_pc1_m
*label variable gap_cpiauc_pc1_m "Difference between original and modified PCE"

capture noisily drop gmax gmin
capture noisily gen gmax =.
capture noisily gen gmin =.
capture noisily replace gmax =.
capture noisily replace gmin =.

sum gap_cpiauc_pc1_m if gap_cpiauc_pc1_m <.
replace gmax = round(r(max)+0.5,1) if nber_rec == 1
replace gmin = round(r(min)-0.5,1) if gmin > r(min)

sum gap_PCEPI_pc1_m if gap_PCEPI_pc1_m <.
replace gmax = round(r(max)+0.5,1) if nber_rec == 1 & gmax < r(max)
replace gmin = round(r(min)-0.5,1) if gmin > r(min)

replace gmax = 0 if nber_rec == 0 
replace gmin = 0 if nber_rec == 0 
sum gmax if nber_rec == 1
local max = r(mean)
sum gmin if nber_rec == 1 
local min = r(mean)


twoway	(bar gmax mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(bar gmin mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(line gap_cpiauc_pc1_m mo, lpattern(solid) lwidth(thick)) ///
		if cpiaucmod_lin_m <. ///
		,legend(off) ///
		graphregion(color(white)) ///
		xtitle("") xlabel(#6) ///
		ytitle("%") ylabel(#7) yscale(range(`min' `max'))
*legend(pos(6) ring(1) col(2) order(3 1 "NBER Recessions")) ///
		
graph export "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\gap_cpiauc_pc1_m.pdf", replace


twoway	(bar gmax mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(bar gmin mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(line gap_PCEPI_pc1_m mo, lpattern(solid) lwidth(thick)) ///
		if cpiaucmod_lin_m <. ///
		,legend(off) ///
		graphregion(color(white)) ///
		xtitle("") xlabel(#6) ///
		ytitle("%") ylabel(#7) yscale(range(`min' `max'))

*		,legend(pos(6) ring(1) col(2) order(3 4 1 "NBER Recessions")) ///


graph export "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\gap_PCEPI_pc1_m.pdf", replace



*Core index: YOY growth
capture noisily drop gmax gmin
capture noisily gen gmax =.
capture noisily gen gmin =.
capture noisily replace gmax =.
capture noisily replace gmin =.

sum cpilfemod_pc1_m if cpilfemod_lin_m <.
replace gmax = round(r(max)+1,2) if nber_rec == 1
replace gmin = round(r(min)-1,2) if gmin > r(min)

sum CPILFESL_pc1_m if cpilfemod_lin_m <.
replace gmax = round(r(max)+1,2) if nber_rec == 1 & gmax < r(max)
replace gmin = round(r(min)-1,2) if gmin > r(min)

sum PCEPILFEmod_pc1_m if cpilfemod_lin_m <.
replace gmax = round(r(max)+1,2) if nber_rec == 1 & gmax < r(max)
replace gmin = round(r(min)-1,2) if gmin > r(min)

sum PCEPILFE_pc1_m if cpilfemod_lin_m <.
replace gmax = round(r(max)+1,2) if nber_rec == 1 & gmax < r(max)
replace gmin = round(r(min)-1,2) if gmin > r(min)

replace gmax = 0 if nber_rec == 0 
replace gmin = 0 if nber_rec == 0 
sum gmax if nber_rec == 1
local max = r(mean)
sum gmin if nber_rec == 1 
local min = r(mean)


twoway	(bar gmax mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(bar gmin mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(line CPILFESL_pc1_m mo, lpattern(solid)) ///
		(line cpilfemod_pc1_m mo, lwidth(thick) lpattern(dash)) ///
		if cpilfemod_pc1_m <. ///
		,legend(pos(6) ring(1) col(2) order(3 4 1 "NBER Recessions")) ///
		graphregion(color(white)) ///
		xtitle("") xlabel(#6) ///
		ytitle("%") ylabel(#7) yscale(range(`min' `max'))

graph export "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\cpilfe_mod_pc1_m.pdf", replace


twoway	(bar gmax mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(bar gmin mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(line PCEPILFE_pc1_m mo, lpattern(solid)) ///
		(line PCEPILFEmod_pc1_m mo, lwidth(thick) lpattern(dash)) ///
		if PCEPILFEmod_pc1_m <. ///
		,legend(pos(6) ring(1) col(2) order(3 4 1 "NBER Recessions")) ///
		graphregion(color(white)) ///
		xtitle("") xlabel(#6) ///
		ytitle("%") ylabel(#7) yscale(range(`min' `max'))

graph export "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\PCEPILFE_mod_pc1_m.pdf", replace


*Core index: The difference in YOY growth

*gen gap_cpilfe_pc1_m = cpilfemod_pc1_m - CPILFESL_pc1_m
*label variable gap_cpiauc_pc1_m "Difference between original and modified core CPI"

*gen gap_PCEPILFE_pc1_m = PCEPILFEmod_pc1_m - PCEPILFE_pc1_m
*label variable gap_cpiauc_pc1_m "Difference between original and modified core PCE"

capture noisily drop gmax gmin
capture noisily gen gmax =.
capture noisily gen gmin =.
capture noisily replace gmax =.
capture noisily replace gmin =.

sum gap_cpilfe_pc1_m if gap_cpilfe_pc1_m <.
replace gmax = round(r(max)+0.5,1) if nber_rec == 1
replace gmin = round(r(min)-0.5,1) if gmin > r(min)

sum gap_PCEPILFE_pc1_m if gap_PCEPILFE_pc1_m <.
replace gmax = round(r(max)+0.5,1) if nber_rec == 1 & gmax < r(max)
replace gmin = round(r(min)-0.5,1) if gmin > r(min)

replace gmax = 0 if nber_rec == 0 
replace gmin = 0 if nber_rec == 0 
sum gmax if nber_rec == 1
local max = r(mean)
sum gmin if nber_rec == 1 
local min = r(mean)


twoway	(bar gmax mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(bar gmin mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(line gap_cpilfe_pc1_m mo, lpattern(solid) lwidth(thick)) ///
		if gap_cpilfe_pc1_m <. ///
		,legend(off) ///
		graphregion(color(white)) ///
		xtitle("") xlabel(#6) ///
		ytitle("%") ylabel(#9) yscale(range(`min' `max'))
*legend(pos(6) ring(1) col(2) order(3 1 "NBER Recessions")) ///
		
graph export "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\gap_cpilfe_pc1_m.pdf", replace


twoway	(bar gmax mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(bar gmin mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(line gap_PCEPILFE_pc1_m mo, lpattern(solid) lwidth(thick)) ///
		if gap_PCEPILFE_pc1_m <. ///
		,legend(off) ///
		graphregion(color(white)) ///
		xtitle("") xlabel(#6) ///
		ytitle("%") ylabel(#9) yscale(range(`min' `max'))

*		,legend(pos(6) ring(1) col(2) order(3 4 1 "NBER Recessions")) ///


graph export "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\gap_PCEPILFE_pc1_m.pdf", replace


//-----------------------------------------
// Checking the stability of the relation between PCE rent and NRI


// Dummy post recession
gen d = (mo>tm(2009m6))
replace d = . if mri_pch_m == . 

// Dummy post RRI
gen postrri = (mo>tm(2010m3))
replace postrri  = . if mri_pch_m == . 


* 7-month lead monthly growth
gen f7_pcerti_pch_m = f7.pcerti_pch_m if d < .
label variable f7_pcerti_pch_m "PCE Rent (7-mo. lead)"



//graph MRI vs 7-m lead PCE rent

// post great recession dummy
capture gen d = (mo>tm(2009m6))
replace d = . if mri_pch_m == . 
*replace d = . if f7.pcerti_pch_m == . 

capture noisily drop gmax gmin
capture noisily gen gmax =.
capture noisily gen gmin =.

sum f7.pcerti_pch_m if d < .
replace gmax = round(r(max),1) if nber_rec == 1
replace gmin = round(r(min),1)

sum mri_pch_m if d < .
replace gmax = round(r(max),1) if nber_rec == 1 & gmax < r(max)
replace gmin = round(r(min),1) if gmin > r(min)

replace gmax = 0 if nber_rec == 0 
replace gmin = 0 if nber_rec == 0 
sum gmax if nber_rec == 1
local max = r(mean)
sum gmin if nber_rec == 1 
local min = r(mean)

twoway 	(bar gmax mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(bar gmin mo, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(line mri_pch_m mo, lpattern(solid) lwidth(thick)) ///
		(line f7.pcerti_pch_m mo, yaxis(2) lpattern(dash)) ///
		if d < . ///
		, legend(pos(6) ring(1) col(1) order(3 "Marginal Rent Index" 4 "PCE Rent (7-month lead)" 1 "NBER Recessions")) ///
		graphregion(color(white)) ///
		xtitle("") xlabel(#7) ///
		ytitle("Monthly % Change in MRI") ///
		yscale(range(`min' `max')) ylabel(#6) ///
		ytitle("Monthly % Change in PCE", axis(2)) ///
		yscale(range(-0.5 0.5) axis(2))

graph export "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\newey_pce_mri_m.pdf", replace





//-----------------------------------------
// Chow Test
newey f7_pcerti_pch_m i.d##c.mri_pch_m if mri_pc1_m <., lag(12)
outreg2 using "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\pce_mri_m.tex" , replace tex(fragment) label
/*

Regression with Newey–West standard errors      Number of obs     =        228
Maximum lag = 12                                F(  3,       224) =      11.86
                                                Prob > F          =     0.0000

-------------------------------------------------------------------------------
              |             Newey–West
f7_pcerti_p~m | Coefficient  std. err.      t    P>|t|     [95% conf. interval]
--------------+----------------------------------------------------------------
          1.d |  -.0666554   .0242511    -2.75   0.006    -.1144448    -.018866
    mri_pch_m |   .1462495   .0492318     2.97   0.003     .0492328    .2432662
              |
d#c.mri_pch_m |
           1  |   .0504474   .0530095     0.95   0.342    -.0540138    .1549085
              |
        _cons |   .2488583   .0186229    13.36   0.000     .2121599    .2855568
-------------------------------------------------------------------------------
*/





//-----------------------------------------
// Table comparison of inflation rates by Time Periods
// descriptive statistics: 2001m4 - 2017m11

sum *_pca_m if cpiaucmod_pca_m <. 

gen bc = .
label variable bc "Business Cycle"	
replace bc = 1 if mo > m(2001m3)  & mo <= m(2001m11) // nber_rec = 1
label define bcn 1 "Recession between 2001:4 and 2001:11"
replace bc = 2 if mo > m(2001m11)  & mo <= m(2007m12) // nber_rec = 0
label define bcn 2 "Expansion between 2001:12 and 2007:12", add
replace bc = 3 if mo > m(2007m12) & mo <= m(2009m6) // nber_rec = 1
label define bcn 3 "Great Recession between 2008:01 and 2009:06", add
replace bc = 4 if mo > m(2009m6) & mo <= m(2020m2) // nber_rec = 0
label define bcn 4 "Expansion between 2009:07 and 2020:02", add
replace bc = 5 if mo > m(2020m2) & mo <= m(2020m4)  // nber_rec = 1
label define bcn 5 "Recession between 2020:03 and 2020:04", add
replace bc = 6 if mo > m(2020m4) // nber_rec = 0
label define bcn 6 "Expansion since 2020:05", add
label variable bc bcn

keep if cpiaucmod_pca_m <. 
bysort bc: sum *_pca_m
sum *_pca_m

eststo clear 
estpost tabstat ///
	CPIAUCSL_pca_m cpiaucmod_pca_m gap_cpiauc_pca_m ///
	PCEPI_pca_m PCEPImod_pca_m gap_PCEPI_pca_m ///
	CPILFESL_pca_m cpilfemod_pca_m gap_cpilfe_pca_m ///
	PCEPILFE_pca_m PCEPILFEmod_pca_m gap_PCEPILFE_pca_m ///
	, by(bc) statistics(mean sd) columns(statistics) listwise 

	
esttab . using "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\inf_stats.tex", main(mean) aux(sd) ///
	eqlabels(, lhs("Annualized Monthly Rate")) ///
	label replace unstack
	





// ====================================
// Graphs Quarterly 	

cd "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code"

set matsize 4000
set more off
set type double
set scheme s2mono

use  "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\modified_inflation_q_MS20-487.dta", clear

tsset qr



//-----------------------------------------
// normalise lin
foreach var of varlist *_lin*{
sum `var' if qr == tq(2001q3)
local ref = r(mean)
replace `var' = `var' / `ref' * 100
}


// comparison of RRI, NRI, and F4.PCE

// Fig 2
*Level
capture noisily drop gmax gmin
capture noisily gen gmax =.
capture noisily gen gmin =.

sum rri_lin_q if NOI_apt_lin_q <.
*sum rri_lin_q if rri_lin_q  <. & NOI_apt_lin_q <.
replace gmax = round(r(max)+5,20) if nber_rec == 1
replace gmin = round(r(min)-5,20)

sum NOI_apt_lin_q if NOI_apt_lin_q <.
*sum NOI_apt_lin_q if rri_lin_q  <. & NOI_apt_lin_q <.
replace gmax = round(r(max)+5,20) if nber_rec == 1 & gmax < r(max)
replace gmin = round(r(min)-5,20) if gmin > r(min)

sum f4.pcerti_lin_q if NOI_apt_lin_q <.
*sum f4.pcerti_lin_q if rri_lin_q  <. & NOI_apt_lin_q <.
replace gmax = round(r(max)+5,20) if nber_rec == 1 & gmax < r(max)
replace gmin = round(r(min)-5,20) if gmin > r(min)

sum gmax if nber_rec == 1
local max = r(mean)
sum gmin if nber_rec == 1
*local min = r(mean)
local min = min(0,r(mean))
*replace gmax = gmin if nber_rec == 0 
replace gmax = 0 if nber_rec == 0 

twoway	(bar gmax qr, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(line NOI_apt_lin_q qr, lwidth(thick) lpattern(solid)) ///
		(line f4.pcerti_lin_q qr, lpattern(shortdash)) ///
		(line rri_lin_q qr, lwidth(thick) lpattern(dash)) ///
		if NOI_apt_lin_q <., ///
		legend(off) ///
		graphregion(color(white)) ///
		xtitle("") xlabel(#7) ///
		ytitle(" ") yscale(range(`min' `max')) ylabel(#10)
*		legend(pos(6) ring(1) col(2) order(2 "Net Rent Index" 3 "PCE Rent (4-qr. lead)" 4 "Repeat Rent Index" 1 "NBER Recessions")) ///
*		if rri_lin_q  <. & NOI_apt_lin_q <. ///
	
graph export "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\nri_f4pce_rri_lin_q.pdf", replace



// Fig 2
*YOY growth
capture noisily drop gmax gmin
capture noisily gen gmax =.
capture noisily gen gmin =.
 
sum rri_pc1_q if NOI_apt_lin_q <.
*sum rri_pc1_q if rri_lin_q  <. & NOI_apt_lin_q <.
replace gmax = round(r(max)+3,5) if nber_rec == 1
replace gmin = round(r(min)-3,5)

sum NOI_apt_pc1_q if NOI_apt_lin_q <.
*sum NOI_apt_pc1_q if rri_lin_q  <. & NOI_apt_lin_q <.
replace gmax = round(r(max)+3,5) if nber_rec == 1 & gmax < r(max)
replace gmin = round(r(min)-3,5) if gmin > r(min)

sum f4.pcerti_pc1_q if NOI_apt_lin_q <.
*sum f4.pcerti_pc1_q if rri_lin_q  <. & NOI_apt_lin_q <.
replace gmax = round(r(max)+3,5) if nber_rec == 1 & gmax < r(max)
replace gmin = round(r(min)-3,5) if gmin > r(min)

replace gmax = 0 if nber_rec == 0 
replace gmin = 0 if nber_rec == 0 
sum gmax if nber_rec == 1
local max = r(mean)
sum gmin if nber_rec == 1 
local min = r(mean)

twoway	(bar gmax qr, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(bar gmin qr, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(line NOI_apt_pc1_q qr, lwidth(thick) lpattern(solid)) ///
		(line f4.pcerti_pc1_q qr, lpattern(shortdash)) ///
		(line rri_pc1_q qr, lwidth(thick) lpattern(dash)) ///
		if NOI_apt_lin_q <. ///
		,legend(pos(6) ring(1) col(2) order(3 "Net Rent Index" 4 "PCE Rent (4-qr. lead)" 5 "Repeat Rent Index" 1 "NBER Recessions")) ///
		graphregion(color(white)) ///
		xtitle("") xlabel(#7) ///
		ytitle("%") yscale(range(`min' `max'))
*		if rri_lin_q  <. & NOI_apt_lin_q <. ///
		
graph export "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\nri_f4pce_rri_pc1_q.pdf", replace


// comparison of RRI and MRI

*Level
capture noisily drop gmax gmin
capture noisily gen gmax =.
capture noisily gen gmin =.
capture noisily replace gmax =.
capture noisily replace gmin =.

sum mri_lin_q if mri_lin_q <.
replace gmax = round(r(max)+5,10) if nber_rec == 1
replace gmin = round(r(min)-5,10) if gmin > r(min)

sum rri_lin_q if mri_lin_q <.
replace gmax = round(r(max)+5,10) if nber_rec == 1 & gmax < r(max)
replace gmin = round(r(min)-5,10) if gmin > r(min)

sum gmax if nber_rec == 1
local max = r(mean)
sum gmin if nber_rec == 1
local min = min(0,r(mean))
replace gmax = 0 if nber_rec == 0 
*replace gmax = gmin if nber_rec == 0 

twoway	(bar gmax qr, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(line rri_lin_q qr, lwidth(thick) lpattern(dash)) ///
		(line mri_lin_q qr, lwidth(thick) lpattern(solid)) ///
		if mri_lin_q <., ///
		legend(off) ///
		graphregion(color(white)) ///
		xtitle("") xlabel(#7) ///
		ytitle(" ") ylabel(#10) yscale(range(`min' `max'))
		*legend(pos(6) ring(1) col(2) order(2 3 1 "NBER Recessions")) ///
		
graph export "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\rri_mri_lin_q.pdf", replace



*quarterly growth
capture noisily drop gmax gmin
capture noisily gen gmax =.
capture noisily gen gmin =.
capture noisily replace gmax =.
capture noisily replace gmin =.

sum mri_pch_q if mri_lin_q <.
replace gmax = round(r(max)+5,5) if nber_rec == 1
replace gmin = round(r(min)-5,5) if gmin > r(min)

sum rri_pch_q if mri_lin_q <.
replace gmax = round(r(max)+5,5) if nber_rec == 1 & gmax < r(max)
replace gmin = round(r(min)-5,5) if gmin > r(min)

replace gmax = 0 if nber_rec == 0 
replace gmin = 0 if nber_rec == 0 
sum gmax if nber_rec == 1
local max = r(mean)
sum gmin if nber_rec == 1 
local min = r(mean)


twoway	(bar gmax qr, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(bar gmin qr, fcolor(gs12) lcolor(gs13) lwidth(none) lpattern(blank)) ///
		(line rri_pch_q qr, lwidth(thick) lpattern(dash)) ///
		(line mri_pch_q qr, lwidth(thick) lpattern(solid)) ///
		if mri_lin_q <. ///
		,legend(pos(6) ring(1) col(2) order(4 "Marginal Rent Index" 3 "Repeat Rent Index" 1 "NBER Recessions")) ///
		graphregion(color(white)) ///
		xtitle("") xlabel(#7) ///
		ytitle("%") yscale(range(`min' `max'))

graph export "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\rri_mri_pch_q.pdf", replace



// Cross correlation between YOY RRI, NRI, and 4-quarter lead in PCE rent
										//rri_pc1_q: tm(20001q4) - tm(2010q1)
										// mri_pc1_q: tm(2002q1) - 
// Table 1
pwcorr NOI_apt_pc1_q rri_pc1_q f4.pcerti_pc1_q pcerti_pc1_q ///
	if rri_pc1_q  <. & mri_pc1_q < . 
matrix A = r(C)
esttab matrix(A,fmt(%5.2f)) using "C:\Users\juy18\Dropbox\ACY_Inflation_Rates\Paper\JMCB 2020\Code\corr_YOY_RRI_NRI_L4PCE.tex", replace

	

// ====================================
// CPPI and cap rates
// Data for cppi_cr_apt.pdf can be obtained from https://www.rcanalytics.com/

